@@ -4,7 +4,7 @@ from logging import Logger
 from socket import timeout
 
 from rcon.exceptions import ConfigReadError
-from rcon.exceptions import RequestIdMismatch
+from rcon.exceptions import SessionTimeout
 from rcon.exceptions import UserAbort
 from rcon.exceptions import WrongPassword
 
@@ -18,7 +18,7 @@ ERRORS = {
     ConnectionRefusedError: (3, 'Connection refused.'),
     (TimeoutError, timeout): (4, 'Connection timed out.'),
     WrongPassword: (5, 'Wrong password.'),
-    RequestIdMismatch: (6, 'Session timed out.')
+    SessionTimeout: (6, 'Session timed out.')
 }
 
 
@@ -28,7 +28,7 @@ class ErrorHandler:
     __slots__ = ('logger', 'exit_code')
 
     def __init__(self, logger: Logger):
-        """Sets the logger."""
+        """Set the logger."""
         self.logger = logger
         self.exit_code = 0
 
@@ -36,7 +36,7 @@ class ErrorHandler:
         return self
 
     def __exit__(self, _, value: Exception, __):
-        """Checks for connection errors and exits respectively."""
+        """Check for common errors and exit respectively."""
         if value is None:
             return True
 
