@@ -1,8 +1,9 @@
-"""RCON exceptions."""
+"""Common exceptions."""
 
 __all__ = [
     'ConfigReadError',
-    'RequestIdMismatch',
+    'EmptyResponse',
+    'SessionTimeout',
     'UserAbort',
     'WrongPassword'
 ]
@@ -12,14 +13,12 @@ class ConfigReadError(Exception):
     """Indicates an error while reading the configuration."""
 
 
-class RequestIdMismatch(Exception):
-    """Indicates a mismatch in request IDs."""
+class EmptyResponse(Exception):
+    """Indicates an empty response from the server."""
 
-    def __init__(self, sent: int, received: int):
-        """Sets the IDs that have been sent and received."""
-        super().__init__()
-        self.sent = sent
-        self.received = received
+
+class SessionTimeout(Exception):
+    """Indicates that the session timed out."""
 
 
 class UserAbort(Exception):
